"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
var request_interceptor_1 = __importDefault(require("./request-interceptor"));
var types_1 = require("./types");
function initializeRequestRouter(service, routes) {
    service.log("RESTApiService : Initializing requests router (routesCount=" + routes.length + ")");
    service.expressApp.options('*', function (expressRequest, expressResponse) {
        expressResponse.status(200).end();
    });
    for (var _i = 0, routes_1 = routes; _i < routes_1.length; _i++) {
        var routeDescriptor = routes_1[_i];
        var route = {
            method: routeDescriptor[0],
            uri: routeDescriptor[1],
            controller: routeDescriptor[2],
            private: routeDescriptor[3] || false
        };
        service.log(' - Registering route...', route.method, route.uri, route.private ? '(private)' : '');
        var requestInterceptor = request_interceptor_1.default(route, service.authorizer, service);
        var httpServerRequestHandler = service.expressApp[route.method.toLocaleLowerCase()].bind(service.expressApp);
        httpServerRequestHandler(route.uri, requestInterceptor);
    }
    service.expressApp.all('*', function (expressRequest, expressResponse) {
        expressResponse.status(404).end();
        service.log("" + types_1.ConsoleColor.red + expressRequest.id + " RESPONSE : 404");
    });
}
exports.default = initializeRequestRouter;
