/// <reference types="node" />
import { CorsOptions } from 'cors';
import { Server } from 'http';
import { Application, IRouterMatcher, Request, Response } from 'express';
interface PlainObjectValues {
    [key: string]: bigint | boolean | null | number | string | symbol | undefined | Record<string, any> | PlainObjectValues;
}
export declare type ObjectValues<T extends PlainObjectValues> = T[keyof T];
export declare type ObjectKeys<T extends PlainObjectValues> = keyof T;
declare module 'express-serve-static-core' {
    interface Request {
        id?: string;
    }
}
export declare const API_AUTH_REQUIRED = true;
export declare const ConsoleColor: {
    readonly green: "\u001B[32m$";
    readonly red: "\u001B[31m";
    readonly yellow: "\u001B[33m";
    readonly reset: "\u001B[0m";
};
export declare type ConsoleColor = ObjectValues<typeof ConsoleColor>;
declare type callbackFunction = (error?: Error) => void;
export interface RESTApiServiceHTTPServer extends Server {
    shutdown: (callback: callbackFunction) => void;
    forceShutdown: (callback: callbackFunction) => void;
}
export declare type RESTApiServiceExpressApp = Application;
export declare type RESTApiServiceHTTPServerRequest = Request;
export declare type RESTApiServiceHTTPServerResponse = Response;
export declare type RESTApiServiceHTTPServerCorsOptions = CorsOptions | undefined;
export declare type RESTApiServiceExpressAppRequestHandler = IRouterMatcher<RESTApiServiceHTTPServer>;
export declare type RESTApiServiceRequestAuthorizer = (token: string) => boolean | Promise<boolean>;
export declare class RESTApiServiceRequestMethods {
    readonly POST: string;
    readonly PUT: string;
    readonly PATCH: string;
    readonly DELETE: string;
    readonly GET: string;
}
export declare type RESTApiServiceURIPattern = string;
export declare type RESTApiServicePrivateFlag = boolean;
export declare type RESTApiServiceRoute = [keyof RESTApiServiceRequestMethods, RESTApiServiceURIPattern, RESTApiServiceController, RESTApiServicePrivateFlag?];
export interface RESTApiServiceInstance {
    readonly port: number;
    readonly authorizer: RESTApiServiceRequestAuthorizer;
    readonly expressApp: RESTApiServiceExpressApp;
    logErrors: boolean;
    verbose: boolean;
    log: (...args: unknown[]) => void;
}
export declare type RESTApiServiceHTTPSCredentials = {
    key: string;
    cert: string;
};
declare type RESTApiServiceOptionsHTTP = {
    readonly protocol?: 'http';
    readonly cors?: RESTApiServiceHTTPServerCorsOptions;
    readonly port?: number;
    readonly verbose?: boolean;
    readonly auth?: RESTApiServiceRequestAuthorizer;
    readonly logErrors?: boolean;
};
declare type RESTApiServiceOptionsHTTPS = {
    readonly protocol: 'https';
    readonly credentials: RESTApiServiceHTTPSCredentials;
    readonly cors?: RESTApiServiceHTTPServerCorsOptions;
    readonly port?: number;
    readonly verbose?: boolean;
    readonly auth?: RESTApiServiceRequestAuthorizer;
    readonly logErrors?: boolean;
};
export declare type RESTApiServiceEffectiveOptions = {
    readonly protocol: 'http' | 'https';
    readonly cors: RESTApiServiceHTTPServerCorsOptions;
    readonly port: number;
    readonly verbose: boolean;
    readonly auth: RESTApiServiceRequestAuthorizer;
    readonly logErrors: boolean;
    readonly credentials?: RESTApiServiceHTTPSCredentials;
};
export declare type RESTApiServiceOptions = RESTApiServiceOptionsHTTP | RESTApiServiceOptionsHTTPS;
export interface RESTApiServiceRouteDescriptor {
    readonly method: keyof RESTApiServiceRequestMethods;
    readonly uri: RESTApiServiceURIPattern;
    readonly controller: RESTApiServiceController;
    readonly private: RESTApiServicePrivateFlag;
}
export interface RESTApiServiceRequestPayload {
    readonly body: unknown;
    readonly params: unknown;
    readonly query: unknown;
}
export declare type RESTApiServiceRequestInterceptor = (request: RESTApiServiceHTTPServerRequest, response: RESTApiServiceHTTPServerResponse) => Promise<void>;
export declare type RESTApiServiceRequestResponder = (statusCode: number, responseData?: Record<string, any>) => void;
export declare type RESTApiServiceController = (response: RESTApiServiceRequestResponder, payload: RESTApiServiceRequestPayload, token: string) => (undefined | void) | Promise<undefined | void>;
export declare const RESTApiServiceErrorCode: {
    readonly INVALID_OPTIONS_TYPE: 90;
    readonly INVALID_OPTIONS_PORT: 91;
    readonly INVALID_OPTIONS_VERBOSE: 92;
    readonly INVALID_OPTIONS_LOG_ERRORS: 93;
    readonly INVALID_OPTIONS_CORS: 94;
    readonly INVALID_OPTIONS_AUTH: 95;
    readonly INVALID_OPTIONS_PROTOCOL: 96;
    readonly INVALID_OPTIONS_CREDENTIALS: 97;
    readonly INVALID_OPTIONS_CREDENTIALS_CERTIFICATE: 98;
    readonly INVALID_OPTIONS_CREDENTIALS_KEY: 99;
    readonly INVALID_ROUTES_COLLECTION: 100;
    readonly INVALID_ROUTE_TYPE: 101;
    readonly INVALID_ROUTE_METHOD: 102;
    readonly INVALID_ROUTE_URI: 103;
    readonly INVALID_ROUTE_CONTROLLER: 104;
    readonly INVALID_ROUTE_PRIVATE_FLAG: 105;
};
export declare type RESTApiServiceErrorCode = ObjectValues<typeof RESTApiServiceErrorCode>;
export declare class RESTApiServiceError extends Error {
    constructor(message: string, errCode: RESTApiServiceErrorCode);
    code: RESTApiServiceErrorCode;
}
export {};
