"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
var service_error_1 = __importDefault(require("./service-error"));
var types_1 = require("./types");
var OptionsValidator = (function () {
    function OptionsValidator() {
    }
    OptionsValidator.checkOptionsObject = function (x) {
        if (typeof x !== 'object' || x === null || Array.isArray(x)) {
            throw new service_error_1.default('Options must be an object', types_1.RESTApiServiceErrorCode.INVALID_OPTIONS_TYPE);
        }
    };
    OptionsValidator.checkProtocol = function (x) {
        if (typeof x !== 'string' || !['https', 'http'].includes(x)) {
            throw new service_error_1.default('Options.protocol must be "http" or "https"', types_1.RESTApiServiceErrorCode.INVALID_OPTIONS_PROTOCOL);
        }
    };
    OptionsValidator.checkPort = function (x) {
        if (typeof x !== 'number') {
            throw new service_error_1.default('Options.port must be a number', types_1.RESTApiServiceErrorCode.INVALID_OPTIONS_PORT);
        }
    };
    OptionsValidator.checkVerbose = function (x) {
        if (typeof x !== 'boolean') {
            throw new service_error_1.default('Options.verbose must be a boolean', types_1.RESTApiServiceErrorCode.INVALID_OPTIONS_VERBOSE);
        }
    };
    OptionsValidator.checkCors = function (x) {
        if (typeof x !== 'object' || x === null || Array.isArray(x)) {
            throw new service_error_1.default('Options.cors must be an object', types_1.RESTApiServiceErrorCode.INVALID_OPTIONS_CORS);
        }
    };
    OptionsValidator.checkAuth = function (x) {
        if (typeof x !== 'function') {
            throw new service_error_1.default('Options.auth must be a function', types_1.RESTApiServiceErrorCode.INVALID_OPTIONS_AUTH);
        }
    };
    OptionsValidator.checkLogErrors = function (x) {
        if (typeof x !== 'boolean') {
            throw new service_error_1.default('Options.logErrors must be a boolean', types_1.RESTApiServiceErrorCode.INVALID_OPTIONS_LOG_ERRORS);
        }
    };
    OptionsValidator.checkCredentials = function (x) {
        if (typeof x !== 'object' || x === null || Array.isArray(x)) {
            throw new service_error_1.default('Options.credentials must be set when protocol="https"', types_1.RESTApiServiceErrorCode.INVALID_OPTIONS_CREDENTIALS);
        }
        if (typeof x.cert !== 'string') {
            throw new service_error_1.default('Options.credentials.cert must be a string', types_1.RESTApiServiceErrorCode.INVALID_OPTIONS_CREDENTIALS_CERTIFICATE);
        }
        if (typeof x.key !== 'string') {
            throw new service_error_1.default('Options.credentials.key must be a string', types_1.RESTApiServiceErrorCode.INVALID_OPTIONS_CREDENTIALS_KEY);
        }
    };
    return OptionsValidator;
}());
exports.OptionsValidator = OptionsValidator;
function validateOptions(o) {
    var hasOption = function (p) {
        return Object.prototype.hasOwnProperty.call(o, p);
    };
    OptionsValidator.checkOptionsObject(o);
    if (hasOption('protocol'))
        OptionsValidator.checkProtocol(o.protocol);
    if (hasOption('port'))
        OptionsValidator.checkPort(o.port);
    if (hasOption('verbose'))
        OptionsValidator.checkVerbose(o.verbose);
    if (hasOption('cors'))
        OptionsValidator.checkCors(o.cors);
    if (hasOption('auth'))
        OptionsValidator.checkAuth(o.auth);
    if (hasOption('logErrors'))
        OptionsValidator.checkVerbose(o.logErrors);
    if (o.protocol === 'https')
        OptionsValidator.checkCredentials(o.credentials);
}
exports.default = validateOptions;
