"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
var service_error_1 = __importDefault(require("./service-error"));
var types_1 = require("./types");
var RoutesValidator = (function () {
    function RoutesValidator() {
    }
    RoutesValidator.checkCollectionType = function (r) {
        if (!Array.isArray(r)) {
            throw new service_error_1.default('First argument must be an array', types_1.RESTApiServiceErrorCode.INVALID_ROUTES_COLLECTION);
        }
    };
    RoutesValidator.checkRouteType = function (x, i) {
        if (!Array.isArray(x)) {
            throw new service_error_1.default("Route in index " + i + " must be an array", types_1.RESTApiServiceErrorCode.INVALID_ROUTE_TYPE);
        }
    };
    RoutesValidator.checkMethod = function (x, i) {
        if (typeof x !== 'string' ||
            !Object.prototype.hasOwnProperty.call(RoutesValidator.allowedMethods, x)) {
            throw new service_error_1.default("Invalid http method set for route with index " + i + ". Allowed methods are : " + Object.keys(RoutesValidator.allowedMethods), types_1.RESTApiServiceErrorCode.INVALID_ROUTE_METHOD);
        }
    };
    RoutesValidator.checkURI = function (x, i) {
        if (typeof x !== 'string') {
            throw new service_error_1.default("Invalid URI set for route with index " + i + " . Expecting a string", types_1.RESTApiServiceErrorCode.INVALID_ROUTE_URI);
        }
    };
    RoutesValidator.checkController = function (x, i) {
        if (typeof x !== 'function') {
            throw new service_error_1.default("Invalid Controller set for route with index " + i + ". Expecting a function", types_1.RESTApiServiceErrorCode.INVALID_ROUTE_CONTROLLER);
        }
    };
    RoutesValidator.checkPrivateFlag = function (x, i) {
        if (typeof x !== 'boolean') {
            throw new service_error_1.default("Invalid Private Flag used in route with index " + i + ". Expecting a boolean", types_1.RESTApiServiceErrorCode.INVALID_ROUTE_PRIVATE_FLAG);
        }
    };
    RoutesValidator.allowedMethods = new types_1.RESTApiServiceRequestMethods();
    return RoutesValidator;
}());
exports.RoutesValidator = RoutesValidator;
function validateRoute(route, i) {
    RoutesValidator.checkRouteType(route, i);
    RoutesValidator.checkMethod(route[0], i);
    RoutesValidator.checkURI(route[1], i);
    RoutesValidator.checkController(route[2], i);
    if (route[3] !== undefined)
        RoutesValidator.checkPrivateFlag(route[3], i);
}
exports.validateRoute = validateRoute;
function validateRoutes(routes) {
    RoutesValidator.checkCollectionType(routes);
    for (var i = 0; i < routes.length; i++)
        validateRoute(routes[i], i);
}
exports.default = validateRoutes;
